gnucash maint: Multiple changes pushed

Frank H.Ellenberger fell at code.gnucash.org
Fri May 3 07:16:06 EDT 2019


Updated	 via  https://github.com/Gnucash/gnucash/commit/53e4e8a9 (commit)
	 via  https://github.com/Gnucash/gnucash/commit/275463d3 (commit)
	from  https://github.com/Gnucash/gnucash/commit/8d71fcaf (commit)



commit 53e4e8a9768dacf18359d1280e114d01f7d8fa22
Author: Frank H. Ellenberger <frank.h.ellenberger at gmail.com>
Date:   Fri May 3 11:50:31 2019 +0200

    Use standard buttons in "Tip of the Day"

diff --git a/gnucash/gtkbuilder/dialog-totd.glade b/gnucash/gtkbuilder/dialog-totd.glade
index 17896d66e..c8bb7db01 100644
--- a/gnucash/gtkbuilder/dialog-totd.glade
+++ b/gnucash/gtkbuilder/dialog-totd.glade
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!-- Generated with glade 3.20.0 -->
+<!-- Generated with glade 3.22.1 -->
 <interface>
   <requires lib="gtk+" version="3.10"/>
   <object class="GtkDialog" id="totd_dialog">
@@ -10,6 +10,9 @@
     <property name="default_height">300</property>
     <property name="type_hint">dialog</property>
     <signal name="response" handler="gnc_totd_dialog_response_cb" swapped="no"/>
+    <child>
+      <placeholder/>
+    </child>
     <child internal-child="vbox">
       <object class="GtkBox" id="dialog-vbox3">
         <property name="visible">True</property>
@@ -23,12 +26,13 @@
             <property name="layout_style">end</property>
             <child>
               <object class="GtkButton" id="back-button">
-                <property name="label" translatable="yes">_Back</property>
+                <property name="label">gtk-media-previous</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
                 <property name="receives_default">True</property>
                 <property name="use_underline">True</property>
+                <property name="use_stock">True</property>
               </object>
               <packing>
                 <property name="expand">False</property>
@@ -38,12 +42,13 @@
             </child>
             <child>
               <object class="GtkButton" id="forward-button">
-                <property name="label" translatable="yes">_Forward</property>
+                <property name="label">gtk-media-next</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
                 <property name="receives_default">True</property>
                 <property name="use_underline">True</property>
+                <property name="use_stock">True</property>
               </object>
               <packing>
                 <property name="expand">False</property>
@@ -53,12 +58,13 @@
             </child>
             <child>
               <object class="GtkButton" id="close-button">
-                <property name="label" translatable="yes">_Close</property>
+                <property name="label">gtk-close</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
                 <property name="receives_default">True</property>
                 <property name="use_underline">True</property>
+                <property name="use_stock">True</property>
               </object>
               <packing>
                 <property name="expand">False</property>
@@ -125,10 +131,10 @@
                         <property name="border_width">6</property>
                         <property name="editable">False</property>
                         <property name="wrap_mode">word</property>
-                        <property name="accepts_tab">False</property>
                         <property name="left_margin">5</property>
                         <property name="right_margin">5</property>
                         <property name="cursor_visible">False</property>
+                        <property name="accepts_tab">False</property>
                       </object>
                       <packing>
                         <property name="expand">True</property>

commit 275463d3b8a3ab9cad83c6e771ee75c665888475
Author: Frank H. Ellenberger <frank.h.ellenberger at gmail.com>
Date:   Wed May 1 00:57:24 2019 +0200

    N[I18N] "Next" is the new "Forward"
    
    From GTK2 to 3 the button label changed. So several texts referenced a
    no longer existing button.
    
    For changed strings also unify quotation to \"

diff --git a/gnucash/gnome-utils/assistant-xml-encoding.c b/gnucash/gnome-utils/assistant-xml-encoding.c
index 4f5aa69cb..368ef241a 100644
--- a/gnucash/gnome-utils/assistant-xml-encoding.c
+++ b/gnucash/gnome-utils/assistant-xml-encoding.c
@@ -1,5 +1,5 @@
 /**********************************************************************
- * assistant-xml-encoding.c -- Coversion of old XML file
+ * assistant-xml-encoding.c -- Conversion of old XML file
  * Copyright (C) 2006 Andreas Koehler <andi5.py at gmx.net>
  * Copyright (C) 2011 Robert Fewell
  *
@@ -174,6 +174,7 @@ void gxi_add_custom_enc_clicked_cb (GtkButton *button, GncXmlImportData *data);
 void gxi_selected_enc_activated_cb (GtkTreeView *view, GtkTreePath *path, GtkTreeViewColumn *column, GncXmlImportData *data);
 void gxi_remove_enc_clicked_cb (GtkButton *button, GncXmlImportData *data);
 
+/* Translators: Run the assistent in your language to see GTK's translation of the button labels. */
 static const gchar *encodings_doc_string = N_(
             "\nThe file you are trying to load is from an older version of "
             "GnuCash. The file format in the older versions was missing the "
@@ -187,21 +188,21 @@ static const gchar *encodings_doc_string = N_(
             "file. On the next page GnuCash will show the resulting texts when "
             "using this guess. You have to check whether the words look as "
             "expected. Either everything looks fine and you can simply press "
-            "'Forward'. Or the words contain unexpected characters, in which "
+            "\"Next\". Or the words contain unexpected characters, in which "
             "case you should select different character encodings to see "
             "different results. You may have to edit the list of character "
             "encodings by clicking on the respective button."
             "\n\n"
-            "Press 'Forward' now to select the correct character encoding for "
+            "Press \"Next\" now to select the correct character encoding for "
             "your data file.\n");
 
 static const gchar *encodings_doc_page_title = N_("Ambiguous character encoding");
 
 static const gchar *finish_convert_string = N_(
-            "The file has been loaded successfully. If you click 'Apply' it will be saved "
+            "The file has been loaded successfully. If you click \"Apply\" it will be saved "
             "and reloaded into the main application. That way you will have a working "
             "file as backup in the same directory.\n\n"
-            "You can also go back and verify your selections by clicking on 'Back'.");
+            "You can also go back and verify your selections by clicking on \"Back\".");
 
 /* The debugging module that this .o belongs to. */
 static QofLogModule log_module = GNC_MOD_ASSISTANT;
diff --git a/gnucash/gnome/assistant-acct-period.c b/gnucash/gnome/assistant-acct-period.c
index 06e9bb4ed..f338e2f98 100644
--- a/gnucash/gnome/assistant-acct-period.c
+++ b/gnucash/gnome/assistant-acct-period.c
@@ -363,12 +363,14 @@ ap_assistant_book_prepare (GtkAssistant *assistant, gpointer user_data)
     nacc = gnc_account_n_descendants (gnc_book_get_root_account (currbook));
 
     /* Display the book info */
+
     period_text =
+	/* Translators: Run the assistent in your language to see GTK's translation of the button labels. */
         _("You have asked for a book to be created. This book "
           "will contain all transactions up to midnight %s "
           "(for a total of %d transactions spread over %d accounts).\n\n "
-          "Amend the Title and Notes or Click on 'Forward' to proceed.\n "
-          "Click on 'Back' to adjust the dates or 'Cancel'.");
+          "Amend the Title and Notes or Click on \"Next\" to proceed.\n "
+          "Click on \"Back\" to adjust the dates or \"Cancel\".");
     str = g_strdup_printf (period_text, close_date_str, ntrans, nacc);
     gtk_label_set_text (GTK_LABEL(info->book_details), str);
     g_free (str);
@@ -400,8 +402,8 @@ ap_assistant_apply_prepare (GtkAssistant *assistant, gpointer user_data)
     char *str;
     const char *apply_text =
         _("The book will be created with the title %s when you "
-          "click on 'Apply'. Click on 'Back' to adjust, "
-	  "or 'Cancel' to not create any book.");
+          "click on \"Apply\". Click on \"Back\" to adjust, "
+	  "or \"Cancel\" to not create any book.");
 
     btitle = gtk_entry_get_text (GTK_ENTRY(info->book_title));
     str = g_strdup_printf (apply_text, btitle);
diff --git a/gnucash/gtkbuilder/assistant-csv-account-import.glade b/gnucash/gtkbuilder/assistant-csv-account-import.glade
index 17aa12fb8..400817281 100644
--- a/gnucash/gtkbuilder/assistant-csv-account-import.glade
+++ b/gnucash/gtkbuilder/assistant-csv-account-import.glade
@@ -27,14 +27,14 @@
           <object class="GtkLabel" id="start_label">
             <property name="visible">True</property>
             <property name="can_focus">False</property>
-            <property name="label" translatable="yes">
+            <property name="label" translatable="yes" comments="Run the assistent in your language to see GTK's translation of the button labels.">
 This assistant will help you import Accounts from a file.
 
-The file must be in the same format as that exported as this is a fixed format import which can be seen by looking at a file created by using the 'Export Account Tree to CSV' export menu option.
+The file must be in the same format as that exported as this is a fixed format import which can be seen by looking at a file created by using the "Export Account Tree to CSV" export menu option.
 
 If the account is missing, based on the full account name, it will be added as long as the security / currency specified exists. If the account exists, then four fields will be updated. These are code, description, notes and color.
 
-Click on 'Forward' to proceed or 'Cancel' to Abort Import.
+Click on "Next" to proceed or "Cancel" to Abort Import.
 </property>
             <property name="justify">center</property>
             <property name="wrap">True</property>
diff --git a/gnucash/gtkbuilder/assistant-csv-price-import.glade b/gnucash/gtkbuilder/assistant-csv-price-import.glade
index 655d26cdd..ee3c9575a 100644
--- a/gnucash/gtkbuilder/assistant-csv-price-import.glade
+++ b/gnucash/gtkbuilder/assistant-csv-price-import.glade
@@ -61,7 +61,7 @@ Lastly, for repeated imports the preview page has buttons to Load and Save the s
 
 This operation is not reversable, so make sure you have a working backup.
 
-Click on 'Forward' to proceed or 'Cancel' to Abort Import.</property>
+Click on "Next" to proceed or "Cancel" to Abort Import.</property>
         <property name="wrap">True</property>
       </object>
       <packing>
@@ -82,7 +82,7 @@ Click on 'Forward' to proceed or 'Cancel' to Abort Import.</property>
             <property name="visible">True</property>
             <property name="can_focus">False</property>
             <property name="label" translatable="yes">
-Select location and file name for the Import, then click 'OK'...
+Select location and file name for the Import, then click "OK"...
 </property>
             <property name="wrap">True</property>
           </object>
@@ -759,8 +759,8 @@ Select location and file name for the Import, then click 'OK'...
                             <property name="receives_default">False</property>
                             <property name="tooltip_text" translatable="yes">Starting from the first line that is actually imported every second line will be skipped. This option will take the leading lines to skip into account as well.
 For example
-* if 'Leading Lines to Skip' is set to 3, the first line to import will be line 4. Lines 5, 7, 9,... will be skipped.
-* if 'Leading Lines to Skip' is set to 4, the first line to import will be line 5. Lines 6, 8, 10,... will be skipped.</property>
+* if "Leading Lines to Skip" is set to 3, the first line to import will be line 4. Lines 5, 7, 9,... will be skipped.
+* if "Leading Lines to Skip" is set to 4, the first line to import will be line 5. Lines 6, 8, 10,... will be skipped.</property>
                             <property name="halign">start</property>
                             <property name="draw_indicator">True</property>
                             <signal name="toggled" handler="csv_price_imp_preview_skiprows_cb" swapped="no"/>
diff --git a/gnucash/gtkbuilder/assistant-qif-import.glade b/gnucash/gtkbuilder/assistant-qif-import.glade
index d7564f98c..b8ae01fbb 100644
--- a/gnucash/gtkbuilder/assistant-qif-import.glade
+++ b/gnucash/gtkbuilder/assistant-qif-import.glade
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!-- Generated with glade 3.20.0 -->
+<!-- Generated with glade 3.22.1 -->
 <interface>
   <requires lib="gtk+" version="3.10"/>
   <object class="GtkListStore" id="currency_liststore">
@@ -36,11 +36,11 @@
       <object class="GtkLabel" id="start_page">
         <property name="visible">True</property>
         <property name="can_focus">False</property>
-        <property name="label" translatable="yes">GnuCash can import financial data from QIF (Quicken Interchange Format) files written by Quicken/QuickBooks, MS Money, Moneydance, and many other programs. 
+        <property name="label" translatable="yes" comments="Run the assistent in your language to see GTK's translation of the button labels.">GnuCash can import financial data from QIF (Quicken Interchange Format) files written by Quicken/QuickBooks, MS Money, Moneydance, and many other programs. 
 
 The import process has several steps. Your GnuCash accounts will not be changed until you click "Apply" at the end of the process. 
 
-Click "Forward" to start loading your QIF data, or "Cancel" to abort the process. </property>
+Click "Next" to start loading your QIF data, or "Cancel" to abort the process. </property>
         <property name="wrap">True</property>
       </object>
       <packing>
@@ -60,7 +60,7 @@ Click "Forward" to start loading your QIF data, or "Cancel" to abort the process
           <object class="GtkLabel" id="label822">
             <property name="visible">True</property>
             <property name="can_focus">False</property>
-            <property name="label" translatable="yes">Please select a file to load. When you click "Forward", the file will be loaded and analyzed. You may need to answer some questions about the account(s) in the file.
+            <property name="label" translatable="yes" comments="Run the assistent in your language to see GTK's translation of the button labels.">Please select a file to load. When you click "Next", the file will be loaded and analyzed. You may need to answer some questions about the account(s) in the file.
 
 You will have the opportunity to load as many files as you wish, so don't worry if your data is in multiple files. 
 </property>
@@ -447,9 +447,9 @@ Please enter a name for the account. If the file was exported from another accou
           <object class="GtkLabel" id="label816">
             <property name="visible">True</property>
             <property name="can_focus">False</property>
-            <property name="label" translatable="yes">Click "Load another file" if you have more data to import at this time. Do this if you have saved your accounts to separate QIF files.
+            <property name="label" translatable="yes" comments="Run the assistent in your language to see GTK's translation of the button labels.">Click "Load another file" if you have more data to import at this time. Do this if you have saved your accounts to separate QIF files.
 
-Click "Forward" to finish loading files and move to the next step of the QIF import process. </property>
+Click "Next" to finish loading files and move to the next step of the QIF import process. </property>
             <property name="wrap">True</property>
           </object>
           <packing>
@@ -1165,12 +1165,12 @@ If you don't see your exchange listed, or none of the available choices are appr
           <object class="GtkLabel" id="label847694">
             <property name="visible">True</property>
             <property name="can_focus">False</property>
-            <property name="label" translatable="yes">
+            <property name="label" translatable="yes" comments="Run the assistent in your language to see GTK's translation of the button labels.">
 If you are importing a QIF file from a bank or other financial institution, some of the transactions may already exist in your GnuCash accounts. To avoid duplication, GnuCash has tried to identify matches and needs your help to review them.
 
 On the next page you will be shown a list of imported transactions. As you select each one, a list of possible matches will be shown below it. If you find a correct match, click on it. Your selection will be confirmed by a check mark in the "Match?" column.
 
-Click "Forward" to review the possible matches.</property>
+Click "Next" to review the possible matches.</property>
             <property name="wrap">True</property>
           </object>
           <packing>
@@ -1319,10 +1319,8 @@ Click "Cancel" to abort the QIF import process.</property>
         <property name="has_padding">False</property>
       </packing>
     </child>
-    <child internal-child="action_area">
-      <object class="GtkBox" id="assistant-action_area2">
-        <property name="can_focus">False</property>
-      </object>
+    <child>
+      <placeholder/>
     </child>
   </object>
 </interface>
diff --git a/gnucash/gtkbuilder/assistant-stock-split.glade b/gnucash/gtkbuilder/assistant-stock-split.glade
index b2a395ba8..8ffe8fb92 100644
--- a/gnucash/gtkbuilder/assistant-stock-split.glade
+++ b/gnucash/gtkbuilder/assistant-stock-split.glade
@@ -244,7 +244,7 @@
           <object class="GtkLabel" id="stock_cash_label">
             <property name="visible">True</property>
             <property name="can_focus">False</property>
-            <property name="label" translatable="yes">If you received a cash disbursement as a result of the stock split, enter the details of that payment here. Otherwise, just click `Forward'.</property>
+            <property name="label" translatable="yes">If you received a cash disbursement as a result of the stock split, enter the details of that payment here. Otherwise, just click "Next".</property>
             <property name="justify">center</property>
             <property name="wrap">True</property>
           </object>
@@ -417,7 +417,7 @@
       <object class="GtkLabel" id="finish_page_label">
         <property name="visible">True</property>
         <property name="can_focus">False</property>
-        <property name="label" translatable="yes">If you are finished creating the stock split or merger, press `Apply'. You may also press `Back' to review your choices, or `Cancel' to quit without making any changes.</property>
+        <property name="label" translatable="yes">If you are finished creating the stock split or merger, press "Apply". You may also press "Back" to review your choices, or "Cancel" to quit without making any changes.</property>
         <property name="wrap">True</property>
       </object>
       <packing>
diff --git a/gnucash/import-export/aqb/assistant-ab-initial.glade b/gnucash/import-export/aqb/assistant-ab-initial.glade
index 45cfca0c0..1dc8f58e6 100644
--- a/gnucash/import-export/aqb/assistant-ab-initial.glade
+++ b/gnucash/import-export/aqb/assistant-ab-initial.glade
@@ -27,7 +27,7 @@ You first need to apply for Online Banking access at your bank. If your bank  de
 * The Internet address of your bank's Online Banking server
 * For HBCI Online Banking, information about the cryptographic public key of your bank ("Ini-Letter").
 
-This information will be needed in the following. Press "Forward" now.
+This information will be needed in the following. Press "Next" now.
 
 NOTE: NO WARRANTIES FOR ANYTHING. Some banks run a poorly implemented Online Banking server. You should not rely on time-critical transfers through Online Banking, because sometimes the bank does not give you correct feedback when a transfer is rejected.
 
diff --git a/gnucash/import-export/csv-imp/assistant-csv-account-import.c b/gnucash/import-export/csv-imp/assistant-csv-account-import.c
index 443c8f5b1..f8c9940f6 100644
--- a/gnucash/import-export/csv-imp/assistant-csv-account-import.c
+++ b/gnucash/import-export/csv-imp/assistant-csv-account-import.c
@@ -205,7 +205,7 @@ csv_import_file_chooser_selection_changed_cb (GtkFileChooser *chooser,
     GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
     gtk_assistant_set_page_complete (assistant, info->account_page, FALSE);
 
-    /* Enable the forward button based on a valid filename */
+    /* Enable the "Next" button based on a valid filename */
     gtk_assistant_set_page_complete (assistant, info->file_page,
         csv_import_assistant_check_filename (chooser, info));
 }
@@ -255,14 +255,14 @@ void csv_import_hrows_cb (GtkWidget *spin, gpointer user_data)
 /*******************************************************
  * csv_import_assistant_enable_account_forward
  *
- * enaable forward button on account_page if store has rows
+ * enable "Next" button on account_page if store has rows
  *******************************************************/
 static void csv_import_assistant_enable_account_forward (CsvImportInfo *info)
 {
     GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
     gboolean store_has_rows = TRUE;
 
-    /* if the store is empty, disable forward button */
+    /* if the store is empty, disable "Next" button */
     if (gtk_tree_model_iter_n_children (GTK_TREE_MODEL(info->store), NULL) == 0)
         store_has_rows = FALSE;
 
@@ -320,7 +320,7 @@ void csv_import_sep_cb (GtkWidget *radio, gpointer user_data)
     else
         gtk_spin_button_set_value (GTK_SPIN_BUTTON(info->header_row_spin), 0); //reset header spin to 0
 
-    /* if the store has rows, enable forward button */
+    /* if the store has rows, enable "Next" button */
     csv_import_assistant_enable_account_forward (info);
 }
 
@@ -439,7 +439,7 @@ csv_import_assistant_file_page_prepare (GtkAssistant *assistant,
     if (info->starting_dir)
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(info->file_chooser), info->starting_dir);
 
-    /* Disable the Forward Assistant Button */
+    /* Disable the "Next" Assistant Button */
     gtk_assistant_set_page_complete (assistant, info->file_page, FALSE);
 }
 
@@ -451,7 +451,7 @@ csv_import_assistant_account_page_prepare (GtkAssistant *assistant,
     CsvImportInfo *info = user_data;
     csv_import_result res;
 
-    /* Disable the Forward Assistant Button */
+    /* Disable the "Next" Assistant Button */
     gtk_assistant_set_page_complete (assistant, info->account_page, FALSE);
 
     /* test read one line */
@@ -477,7 +477,7 @@ csv_import_assistant_account_page_prepare (GtkAssistant *assistant,
     else
         gtk_spin_button_set_value (GTK_SPIN_BUTTON(info->header_row_spin), 0); //reset header spin to 0
 
-    /* if the store has rows, enable forward button */
+    /* if the store has rows, enable "Next" button */
     csv_import_assistant_enable_account_forward (info);
 }
 
diff --git a/gnucash/import-export/csv-imp/assistant-csv-price-import.cpp b/gnucash/import-export/csv-imp/assistant-csv-price-import.cpp
index 0842257ac..c539a4256 100644
--- a/gnucash/import-export/csv-imp/assistant-csv-price-import.cpp
+++ b/gnucash/import-export/csv-imp/assistant-csv-price-import.cpp
@@ -678,7 +678,7 @@ CsvImpPriceAssist::~CsvImpPriceAssist ()
  * Code related to the file chooser page
  **************************************************/
 
-/* check_for_valid_filename for a valid file to activate the forward button
+/* check_for_valid_filename for a valid file to activate the "Next" button
  */
 bool
 CsvImpPriceAssist::check_for_valid_filename ()
@@ -727,7 +727,7 @@ CsvImpPriceAssist::file_activated_cb ()
 void
 CsvImpPriceAssist::file_selection_changed_cb ()
 {
-    /* Enable the forward button based on a valid filename */
+    /* Enable the "Next" button based on a valid filename */
     gtk_assistant_set_page_complete (csv_imp_asst, file_page,
         check_for_valid_filename ());
 }
@@ -1741,7 +1741,7 @@ void CsvImpPriceAssist::preview_validate_settings ()
 void
 CsvImpPriceAssist::assist_file_page_prepare ()
 {
-    /* Disable the Forward Assistant Button */
+    /* Disable the "Next" Assistant Button */
     gtk_assistant_set_page_complete (csv_imp_asst, file_page, false);
     gtk_assistant_set_page_complete (csv_imp_asst, preview_page, false);
 
@@ -1796,7 +1796,7 @@ CsvImpPriceAssist::assist_preview_page_prepare ()
         // set over_write to false as default
         price_imp->over_write (false);
 
-        /* Disable the Forward Assistant Button */
+        /* Disable the "Next" Assistant Button */
         gtk_assistant_set_page_complete (csv_imp_asst, preview_page, false);
 
         /* Load the data into the treeview. */
diff --git a/gnucash/import-export/csv-imp/assistant-csv-trans-import.cpp b/gnucash/import-export/csv-imp/assistant-csv-trans-import.cpp
index 255142fad..de5cbcb78 100644
--- a/gnucash/import-export/csv-imp/assistant-csv-trans-import.cpp
+++ b/gnucash/import-export/csv-imp/assistant-csv-trans-import.cpp
@@ -682,7 +682,7 @@ CsvImpTransAssist::~CsvImpTransAssist ()
  * Code related to the file chooser page
  **************************************************/
 
-/* check_for_valid_filename for a valid file to activate the forward button
+/* check_for_valid_filename for a valid file to activate the "Next" button
  */
 bool
 CsvImpTransAssist::check_for_valid_filename ()
@@ -731,7 +731,7 @@ CsvImpTransAssist::file_activated_cb ()
 void
 CsvImpTransAssist::file_selection_changed_cb ()
 {
-    /* Enable the forward button based on a valid filename */
+    /* Enable the "Next" button based on a valid filename */
     gtk_assistant_set_page_complete (csv_imp_asst, file_page,
         check_for_valid_filename ());
 }
@@ -1885,7 +1885,7 @@ CsvImpTransAssist::assist_file_page_prepare ()
         g_free (starting_dir);
     }
 
-    /* Disable the Forward Assistant Button */
+    /* Disable the "Next" Assistant Button */
     gtk_assistant_set_page_complete (csv_imp_asst, account_match_page, false);
 }
 
@@ -1933,7 +1933,7 @@ CsvImpTransAssist::assist_preview_page_prepare ()
 
         tx_imp->req_mapped_accts (false);
 
-        /* Disable the Forward Assistant Button */
+        /* Disable the "Next" Assistant Button */
         gtk_assistant_set_page_complete (csv_imp_asst, preview_page, false);
 
         /* Load the data into the treeview. */
@@ -1962,7 +1962,7 @@ CsvImpTransAssist::assist_account_match_page_prepare ()
     gtk_widget_set_sensitive (account_match_view, true);
     gtk_widget_set_sensitive (account_match_btn, true);
 
-    /* Enable the Forward Assistant Button */
+    /* Enable the "Next" Assistant Button */
     gtk_assistant_set_page_complete (csv_imp_asst, account_match_page,
                csv_tximp_acct_match_check_all (store));
 }
diff --git a/gnucash/import-export/qif-imp/assistant-qif-import.c b/gnucash/import-export/qif-imp/assistant-qif-import.c
index 3e89180cf..693d77b96 100644
--- a/gnucash/import-export/qif-imp/assistant-qif-import.c
+++ b/gnucash/import-export/qif-imp/assistant-qif-import.c
@@ -1590,7 +1590,7 @@ gnc_ui_qif_import_load_file_prepare (GtkAssistant  *assistant, gpointer user_dat
     /* Get the file name. */
     path_to_load = gtk_entry_get_text(GTK_ENTRY(wind->filename_entry));
 
-    /* Calculate status for the Assistant Forward Button */
+    /* Calculate status for the Assistant "Next" Button */
     if (strlen(path_to_load) != 0)
     {
        page_status = gnc_ui_qif_import_load_file_complete(assistant, user_data);
@@ -1938,7 +1938,7 @@ gnc_ui_qif_import_load_progress_start_cb(GtkButton * button,
         }
     }
 
-    /* Enable the assistant Forward button */
+    /* Enable the assistant "Next" button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Set Pause and Start buttons */
@@ -1993,7 +1993,7 @@ gnc_ui_qif_import_load_progress_prepare (GtkAssistant  *assistant, gpointer user
     gtk_widget_set_sensitive(wind->load_pause, FALSE);
     gtk_widget_set_sensitive(wind->load_start, TRUE);
 
-    /* Disable the assistant Forward button */
+    /* Disable the assistant "Next" button */
     gtk_assistant_set_page_complete (assistant, page, FALSE);
 }
 
@@ -2124,12 +2124,12 @@ gnc_ui_qif_import_acct_valid_cb(GtkWidget * widget,
 
     if (!acct_name || acct_name[0] == 0)
     {
-        /* Disable the assistant Forward Button */
+        /* Disable the assistant "Next" Button */
         gtk_assistant_set_page_complete (assistant, page, FALSE);
     }
     else
     {
-        /* Enable the assistant Forward Button */
+        /* Enable the assistant "Next" Button */
         gtk_assistant_set_page_complete (assistant, page, TRUE);
     }
 }
@@ -2160,7 +2160,7 @@ gnc_ui_qif_import_loaded_files_prepare (GtkAssistant *assistant,
     scm_name = scm_from_utf8_string(acct_name ? acct_name : "");
     scm_call_2(fix_default, wind->selected_file, scm_name);
 
-    /* Enable the assistant Forward Button */
+    /* Enable the assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     update_file_page(wind);
@@ -2297,7 +2297,7 @@ gnc_ui_qif_import_account_doc_prepare (GtkAssistant *assistant,
 
     PINFO("Total Number of Assistant Pages is %d", gtk_assistant_get_n_pages (assistant));
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Jump to Summary page if load_stop TRUE */
@@ -2334,7 +2334,7 @@ gnc_ui_qif_import_account_match_prepare(GtkAssistant *assistant,
     update_memo_page(wind);
     gnc_unset_busy_cursor(NULL);
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 }
 
@@ -2380,7 +2380,7 @@ gnc_ui_qif_import_catagory_doc_prepare (GtkAssistant *assistant,
 
     PINFO("Total Number of Assistant Pages is %d", gtk_assistant_get_n_pages (assistant));
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Jump to Summary page if load_stop TRUE */
@@ -2415,7 +2415,7 @@ gnc_ui_qif_import_catagory_match_prepare(GtkAssistant *assistant,
     gint num = gtk_assistant_get_current_page (assistant);
     GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* If there are no category mappings, jump this step. */
@@ -2465,7 +2465,7 @@ gnc_ui_qif_import_memo_doc_prepare (GtkAssistant *assistant,
 
     PINFO("Total Number of Assistant Pages is %d", gtk_assistant_get_n_pages (assistant));
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Jump to Summary page if load_stop TRUE */
@@ -2500,7 +2500,7 @@ gnc_ui_qif_import_memo_match_prepare (GtkAssistant *assistant,
     gint num = gtk_assistant_get_current_page (assistant);
     GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* If there are no memo mappings, jump this step. */
@@ -2567,7 +2567,7 @@ gnc_ui_qif_import_currency_prepare(GtkAssistant *assistant,
         gtk_widget_hide (wind->book_option_message);
     }
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 }
 
@@ -2633,7 +2633,7 @@ gnc_ui_qif_import_commodity_doc_prepare (GtkAssistant *assistant,
 
     PINFO("Total Number of Assistant Pages is %d", gtk_assistant_get_n_pages (assistant));
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Jump to Summary page if load_stop TRUE */
@@ -3002,7 +3002,7 @@ gnc_ui_qif_import_convert_progress_start_cb(GtkButton * button,
             wind->load_stop = TRUE;
         }
     }
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Set Pause and Start buttons */
@@ -3054,7 +3054,7 @@ gnc_ui_qif_import_convert_progress_prepare(GtkAssistant *assistant,
     gtk_widget_set_sensitive(wind->convert_pause, FALSE);
     gtk_widget_set_sensitive(wind->convert_start, TRUE);
 
-    /* Disable the assistant Forward button */
+    /* Disable the assistant "Next" button */
     gtk_assistant_set_page_complete (assistant, page, FALSE);
 
     /* Before creating transactions, if this is a new book, let user specify
@@ -3083,7 +3083,7 @@ gnc_ui_qif_import_duplicates_doc_prepare (GtkAssistant *assistant,
 
     PINFO("Total Number of Assistant Pages is %d", gtk_assistant_get_n_pages (assistant));
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 
     /* Jump to Summary page if load_stop TRUE */
@@ -3180,7 +3180,7 @@ gnc_ui_qif_import_duplicates_match_prepare (GtkAssistant *assistant,
     else
         gtk_assistant_set_current_page (assistant, num + 1 );
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 }
 
@@ -3199,7 +3199,7 @@ gnc_ui_qif_import_end_page_prepare (GtkAssistant *assistant,
     gint num = gtk_assistant_get_current_page (assistant);
     GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 }
 
@@ -3287,7 +3287,7 @@ gnc_ui_qif_import_summary_page_prepare (GtkAssistant *assistant,
 
     g_free(text);
 
-    /* Enable the Assistant Forward Button */
+    /* Enable the Assistant "Next" Button */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
 }
 



Summary of changes:
 gnucash/gnome-utils/assistant-xml-encoding.c       | 11 +++---
 gnucash/gnome/assistant-acct-period.c              | 10 +++---
 .../gtkbuilder/assistant-csv-account-import.glade  |  6 ++--
 .../gtkbuilder/assistant-csv-price-import.glade    |  8 ++---
 gnucash/gtkbuilder/assistant-qif-import.glade      | 22 ++++++------
 gnucash/gtkbuilder/assistant-stock-split.glade     |  4 +--
 gnucash/gtkbuilder/dialog-totd.glade               | 16 ++++++---
 .../import-export/aqb/assistant-ab-initial.glade   |  2 +-
 .../import-export/csv-exp/assistant-csv-export.c   | 33 +++++++++---------
 .../csv-imp/assistant-csv-account-import.c         | 14 ++++----
 .../csv-imp/assistant-csv-price-import.cpp         |  8 ++---
 .../csv-imp/assistant-csv-trans-import.cpp         | 10 +++---
 .../import-export/qif-imp/assistant-qif-import.c   | 40 +++++++++++-----------
 13 files changed, 96 insertions(+), 88 deletions(-)



More information about the gnucash-changes mailing list
diff --git a/gnucash/import-export/csv-exp/assistant-csv-export.c b/gnucash/import-export/csv-exp/assistant-csv-export.c
index 75ab2f479..664e694fb 100644
--- a/gnucash/import-export/csv-exp/assistant-csv-export.c
+++ b/gnucash/import-export/csv-exp/assistant-csv-export.c
@@ -76,27 +76,28 @@ void csv_export_end_date_cb (GtkWidget *radio, gpointer user_data);
 void csv_export_file_chooser_file_activated_cb (GtkFileChooser *chooser, CsvExportInfo *info);
 void csv_export_file_chooser_selection_changed_cb (GtkFileChooser *chooser, CsvExportInfo *info);
 
+/* Fixme: Can we simplify the work of translators by splitting in invariant and variant paragraphs? */
 static const gchar *finish_tree_string = N_(
             /* Translators: %s is the file name string. */
-            "The account tree will be exported to the file '%s' when you click 'Apply'.\n\n"
-            "You can also verify your selections by clicking on 'Back' or 'Cancel' to Abort Export.\n");
+            "The account tree will be exported to the file '%s' when you click \"Apply\".\n\n"
+            "You can also verify your selections by clicking on \"Back\" or \"Cancel\" to abort the export.\n");
 
 static const gchar *finish_trans_string = N_(
             /* Translators: %s is the file name string and %u the number of accounts. */
-            "When you click 'Apply', the transactions will be exported to the file '%s' and"
+            "When you click \"Apply\", the transactions will be exported to the file '%s' and"
             " the number of accounts exported will be %u.\n\n"
-            "You can also verify your selections by clicking on 'Back' or 'Cancel' to Abort Export.\n");
+            "You can also verify your selections by clicking on \"Back\" or \"Cancel\" to abort the export.\n");
 
 static const gchar *finish_trans_search_gl_string = N_(
             /* Translators: %s is the file name string. */
-            "When you click 'Apply', the transactions will be exported to the file '%s'.\n\n"
-            "You can also verify your selections by clicking on 'Back' or 'Cancel' to Abort Export.\n");
+            "When you click \"Apply\", the transactions will be exported to the file '%s'.\n\n"
+            "You can also verify your selections by clicking on \"Back\" or \"Cancel\" to abort the export.\n");
 
 static const gchar *start_tree_string = N_(
             "This assistant will help you export the Account Tree to a file\n"
             " with the separator specified below.\n\n"
-            "Select the settings you require for the file and then click 'Forward' to proceed"
-            " or 'Cancel' to Abort Export.\n");
+            "Select the settings you require for the file and then click \"Next\" to proceed"
+            " or \"Cancel\" to abort the export.\n");
 
 static const gchar *start_trans_string = N_(
             "This assistant will help you export the Transactions to a file\n"
@@ -105,8 +106,8 @@ static const gchar *start_trans_string = N_(
             " require further manipulation to get them in a format you can use.\n\n"
             "Each Transaction will appear once in the export and will be listed in"
             " the order the accounts were processed\n\n"
-            "Select the settings you require for the file and then click 'Forward' to proceed"
-            " or 'Cancel' to Abort Export.\n");
+            "Select the settings you require for the file and then click \"Next\" to proceed"
+            " or \"Cancel\" to abort the export.\n");
 
 static const gchar *start_trans_simple_string = N_(
             "This assistant will help you export the Transactions to a file\n"
@@ -117,8 +118,8 @@ static const gchar *start_trans_simple_string = N_(
             " were processed\n\n"
             "By selecting the simple layout, the output will be equivalent to a single"
             " row register view and as such some of the transfer detail could be lost.\n\n"
-            "Select the settings you require for the file and then click 'Forward' to proceed"
-            " or 'Cancel' to Abort Export.\n");
+            "Select the settings you require for the file and then click \"Next\" to proceed"
+            " or \"Cancel\" to abort the export.\n");
 
 
 /**************************************************
@@ -189,7 +190,7 @@ csv_export_file_chooser_selection_changed_cb (GtkFileChooser *chooser,
 {
     GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
 
     /* Enable the forward button based on a valid filename */
     gtk_assistant_set_page_complete (assistant, info->file_page,
         csv_export_assistant_check_filename (chooser, info));
 }
@@ -419,7 +420,7 @@ csv_export_account_changed_cb (GtkTreeSelection *selection,
 
     info->csva.num_accounts = update_accounts_tree (info);
 
     /* Enable the Forward Assistant Button if we have accounts */
     if (info->csva.num_accounts > 0)
         gtk_assistant_set_page_complete (assistant, info->account_page, TRUE);
     else
@@ -686,7 +687,7 @@ csv_export_assistant_account_page_prepare (GtkAssistant *assistant,
 {
     CsvExportInfo *info = user_data;
 
     /* Enable the Forward Assistant Button if we have accounts */
     if (info->csva.num_accounts > 0)
         gtk_assistant_set_page_complete (assistant, info->account_page, TRUE);
     else
@@ -705,7 +706,7 @@ csv_export_assistant_file_page_prepare (GtkAssistant *assistant,
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(info->file_chooser), info->starting_dir);
     gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER(info->file_chooser), "");
 
     /* Disable the Forward Assistant Button */
     gtk_assistant_set_page_complete (assistant, info->file_page, FALSE);
 }
 
@@ -189,7 +190,7 @@ csv_export_file_chooser_selection_changed_cb (GtkFileChooser *chooser,
     GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
 
-    /* Enable the forward button based on a valid filename */
+    /* Enable the "Next" button based on a valid filename */
     gtk_assistant_set_page_complete (assistant, info->file_page,
         csv_export_assistant_check_filename (chooser, info));
@@ -419,7 +420,7 @@ csv_export_account_changed_cb (GtkTreeSelection *selection,
     info->csva.num_accounts = update_accounts_tree (info);
 
-    /* Enable the Forward Assistant Button if we have accounts */
+    /* Enable the "Next" Assistant Button if we have accounts */
     if (info->csva.num_accounts > 0)
         gtk_assistant_set_page_complete (assistant, info->account_page, TRUE);
@@ -686,7 +687,7 @@ csv_export_assistant_account_page_prepare (GtkAssistant *assistant,
     CsvExportInfo *info = user_data;
 
-    /* Enable the Forward Assistant Button if we have accounts */
+    /* Enable the "Next" Assistant Button if we have accounts */
     if (info->csva.num_accounts > 0)
         gtk_assistant_set_page_complete (assistant, info->account_page, TRUE);
@@ -705,7 +706,7 @@ csv_export_assistant_file_page_prepare (GtkAssistant *assistant,
     gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER(info->file_chooser), "");
 
-    /* Disable the Forward Assistant Button */
+    /* Disable the "Next" Assistant Button */
     gtk_assistant_set_page_complete (assistant, info->file_page, FALSE);
 }